@@ -7,12 +7,20 @@ from typing import Dict
 from TEx.core.base_module import BaseModule
 from TEx.core.temp_file import TempFileHandler
 
-logger = logging.getLogger()
+logger = logging.getLogger('TelegramExplorer')
 
 
 class TempFileManager(BaseModule):
     """Temporary File Manager."""
 
+    async def can_activate(self, config: ConfigParser, args: Dict, data: Dict) -> bool:
+        """
+        Abstract Method for Module Activation Function.
+
+        :return:
+        """
+        return True
+
     async def run(self, config: ConfigParser, args: Dict, data: Dict) -> None:
         """Execute Module."""
         if args['purge_temp_files']:
